﻿using Rhino.Geometry;
using Rhino.Runtime.InProcess;
using System;
using System.IO;

namespace TestDraco
{
  class Program
  {
    #region Program static constructor
    static Program()
    {
      RhinoInside.Resolver.Initialize();
    }
    #endregion

    // Use STAThread for this app as we are starting Rhino in a mode that does actually
    // include user interface (we just never show the main window). This allows for things
    // like RhinoApp().RunScript to properly run.
    [System.STAThread]
    static void Main(string[] args)
    {
      Console.WriteLine("Please wait while Rhino is starting...");
      try
      {
        using (new RhinoCore(new string[] { "/NOSPLASH" }, WindowStyle.Hidden))
        {
          var sphere = new Sphere(Plane.WorldYZ, 10.0);
          var mesh = Rhino.Geometry.Mesh.CreateQuadSphere(sphere, 5);
          Console.WriteLine($"Mesh with {mesh.Vertices.Count} vertices created");

          var compression = Rhino.FileIO.DracoCompression.Compress(mesh);
          if (null == compression)
          {
            Console.WriteLine("Error compressing mesh");
            return;
          }

          var path = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);
          var filename = Path.Combine(path, "TestMesh.draco");
          if (compression.Write(filename))
            Console.WriteLine($"Compressed mesh written to {filename}");
          else
            Console.WriteLine("Error writing compressed mesh");

          Console.WriteLine("Press any key to exit...");
          Console.ReadKey();
        }
      } 
      catch (Exception ex)
      {
        Console.Error.WriteLine(ex.Message);
        Console.WriteLine("Press any key to exit...");
        Console.ReadKey();
      }
    }
  }
}
